Package: GeneticsPed
Title: Pedigree and genetic relationship functions
Description: Classes and methods for handling pedigree data. It
  also includes functions to calculate genetic relationship measures
  as relationship and inbreeding coefficients and other utilities.
  Note that package is not yet stable. Use it with care!
Author: Gregor Gorjanc and David A. Henderson <DNADavenator@GMail.Com>,
  with code contributions by Brian Kinghorn and Andrew Percy
  (see file COPYING)
Maintainer: David Henderson <DNADavenator@GMail.Com>
URL: http://rgenetics.org
License: LGPL (>= 2.1) | file LICENSE
biocViews: Genetics
Version: 1.73.0
Depends: R (>= 2.4.0), MASS
Imports: gdata, genetics
Date: 2007-09-20
Suggests: RUnit, gtools
git_url: https://git.bioconductor.org/packages/GeneticsPed
git_branch: devel
git_last_commit: 41bd03e
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: yes
Packaged: 2025-10-30 21:15:40 UTC; biocbuild
